info = {
    "name": "mgo",
    "date_order": "YMD",
    "january": [
        "iməg mbegtug",
        "mbegtug"
    ],
    "february": [
        "imeg àbùbì"
    ],
    "march": [
        "imeg mbəŋchubi"
    ],
    "april": [
        "iməg ngwə̀t"
    ],
    "may": [
        "iməg fog"
    ],
    "june": [
        "iməg ichiibɔd"
    ],
    "july": [
        "iməg àdùmbə̀ŋ"
    ],
    "august": [
        "iməg ichika"
    ],
    "september": [
        "iməg kud"
    ],
    "october": [
        "iməg tèsi'e"
    ],
    "november": [
        "iməg zò"
    ],
    "december": [
        "iməg krizmed"
    ],
    "monday": [
        "aneg 2"
    ],
    "tuesday": [
        "aneg 3"
    ],
    "wednesday": [
        "aneg 4"
    ],
    "thursday": [
        "aneg 5"
    ],
    "friday": [
        "aneg 6"
    ],
    "saturday": [
        "aneg 7"
    ],
    "sunday": [
        "aneg 1"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "fitu'"
    ],
    "month": [
        "iməg"
    ],
    "week": [
        "nkap"
    ],
    "day": [
        "anəg"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "0 day ago": [
            "tèchɔ̀ŋ"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "ikwiri"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "isu"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
